@@ -71,5 +71,7 @@ def static_field():
 replace = dataclasses.replace
 asdict = dataclasses.asdict
 astuple = dataclasses.astuple
+is_dataclass = dataclasses.is_dataclass
+fields = dataclasses.fields
 def unpack(dc) -> tuple:
     return tuple(getattr(dc, field.name) for field in dataclasses.fields(dc))
