@@ -64,7 +64,7 @@ MaskFn = Callable[[Array], Array]
 class CellList:
   """Stores the spatial partition of a system into a cell list.
 
-  See cell_list(...) for details on the construction / specification.
+  See :meth:`cell_list` for details on the construction / specification.
   Cell list buffers all have a common shape, S, where
     * `S = [cell_count_x, cell_count_y, cell_capacity]`
     * `S = [cell_count_x, cell_count_y, cell_count_z, cell_capacity]`
@@ -73,11 +73,11 @@ class CellList:
 
   Attributes:
     position_buffer: An ndarray of floating point positions with shape
-      S + [spatial_dimension].
-    id_buffer: An ndarray of int32 particle ids of shape S. Note that empty
-      slots are specified by id = N where N is the number of particles in the
+      `S + [spatial_dimension]`.
+    id_buffer: An ndarray of int32 particle ids of shape `S`. Note that empty
+      slots are specified by `id = N` where `N` is the number of particles in the
       system.
-    kwarg_buffers: A dictionary of ndarrays of shape S + [...]. This contains
+    kwarg_buffers: A dictionary of ndarrays of shape `S + [...]`. This contains
       side data placed into the cell list.
     did_buffer_overflow: A boolean specifying whether or not the cell list
       exceeded the maximum allocated capacity.
@@ -240,8 +240,8 @@ def cell_list(box_size: Box,
               ) -> CellListFns:
   r"""Returns a function that partitions point data spatially.
 
-  Given a set of points {x_i \in R^d} with associated data {k_i \in R^m} it is
-  often useful to partition the points / data spatially. A simple partitioning
+  Given a set of points :math:`\{x_i \in R^d\}` with associated data :math:`\{k_i \in R^m\}` 
+  it is often useful to partition the points / data spatially. A simple partitioning
   that can be implemented efficiently within XLA is a dense partition into a
   uniform grid called a cell list.
 
@@ -261,7 +261,7 @@ def cell_list(box_size: Box,
   will be set to True.
 
   Args:
-    box_size: A float or an ndarray of shape [spatial_dimension] specifying the
+    box_size: A float or an ndarray of shape `[spatial_dimension]` specifying the
       size of the system. Note, this code is written for the case where the
       boundaries are periodic. If this is not the case, then the current code
       will be slightly less efficient.
@@ -271,7 +271,7 @@ def cell_list(box_size: Box,
       estimated cell capacity to allow for fluctuations in the maximum cell
       occupancy.
   Returns:
-    A CellListFns object that contains two methods, one to allocate the cell
+    A `CellListFns` object that contains two methods, one to allocate the cell
     list and one to update the cell list. The update function can be called
     with either a cell list from which the capacity can be inferred or with
     an explicit integer denoting the capacity. Note that an existing cell list
@@ -573,16 +573,16 @@ def neighbor_list(displacement_or_metric: DisplacementOrMetricFn,
 
      init_fn, apply_fn = simulate.nve(energy_fn, shift, 1e-3)
      exact_init_fn, exact_apply_fn = simulate.nve(exact_energy_fn, shift, 1e-3)
-  
+
      nbrs = neighbor_fn.allocate(R)
      state = init_fn(random.PRNGKey(0), R, neighbor_idx=nbrs.idx)
-  
+
      def body_fn(i, state):
        state, nbrs = state
        nbrs = nbrs.update(state.position)
        state = apply_fn(state, neighbor_idx=nbrs.idx)
        return state, nbrs
-  
+
      step = 0
      for _ in range(20):
        new_state, nbrs = lax.fori_loop(0, 100, body_fn, (state, nbrs))
@@ -596,28 +596,28 @@ def neighbor_list(displacement_or_metric: DisplacementOrMetricFn,
     displacement: A function `d(R_a, R_b)` that computes the displacement
       between pairs of points.
     box_size: Either a float specifying the size of the box or an array of
-      shape [spatial_dim] specifying the box size in each spatial dimension.
+      shape `[spatial_dim]` specifying the box size in each spatial dimension.
     r_cutoff: A scalar specifying the neighborhood radius.
     dr_threshold: A scalar specifying the maximum distance particles can move
       before rebuilding the neighbor list.
     capacity_multiplier: A floating point scalar specifying the fractional
       increase in maximum neighborhood occupancy we allocate compared with the
       maximum in the example positions.
-    disable_cell_list: An optional boolean. If set to True then the neighbor
+    disable_cell_list: An optional boolean. If set to `True` then the neighbor
       list is constructed using only distances. This can be useful for
-      debugging but should generally be left as False.
+      debugging but should generally be left as `False`.
     mask_self: An optional boolean. Determines whether points can consider
       themselves to be their own neighbors.
     custom_mask_function: An optional function. Takes the neighbor array
       and masks selected elements. Note: The input array to the function is
-      (n_particles, m) where the index of particle 1 is in index in the first
+      `(n_particles, m)` where the index of particle 1 is in index in the first
       dimension of the array, the index of particle 2 is given by the value in
       the array
     fractional_coordinates: An optional boolean. Specifies whether positions
-      will be supplied in fractional coordinates in the unit cube, [0, 1]^d.
-      If this is set to True then the box_size will be set to 1.0 and the
-      cell size used in the cell list will be set to cutoff / box_size.
-    format: The format of the neighbor list; see the NeighborListFormat enum
+      will be supplied in fractional coordinates in the unit cube, :math:`[0, 1]^d`.
+      If this is set to True then the `box_size` will be set to `1.0` and the
+      cell size used in the cell list will be set to `cutoff / box_size`.
+    format: The format of the neighbor list; see the :meth:`NeighborListFormat` enum
       for details about the different choices for formats. Defaults to `Dense`.
     **static_kwargs: kwargs that get threaded through the calculation of
       example positions.
@@ -640,7 +640,8 @@ def neighbor_list(displacement_or_metric: DisplacementOrMetricFn,
   cell_size = cutoff
   if fractional_coordinates:
     cell_size = cutoff / box_size
-    box_size = f32(1)
+    box_size = (f32(box_size) if onp.isscalar(box_size)
+                else onp.ones_like(box_size, f32))
 
   use_cell_list = jnp.all(cell_size < box_size / 3.) and not disable_cell_list
   if use_cell_list:
@@ -701,7 +702,7 @@ def neighbor_list(displacement_or_metric: DisplacementOrMetricFn,
     out_idx = out_idx.at[p_index, index].set(idx)
     max_occupancy = jnp.max(cumsum[:, -1])
 
-    return out_idx[:, :-1], max_occupancy
+    return out_idx, max_occupancy
 
   @jit
   def prune_neighbor_list_sparse(position: Array, idx: Array, **kwargs
@@ -728,7 +729,7 @@ def neighbor_list(displacement_or_metric: DisplacementOrMetricFn,
     sender_idx = out_idx.at[index].set(sender_idx)
     max_occupancy = cumsum[-1]
 
-    return jnp.stack((receiver_idx[:-1], sender_idx[:-1])), max_occupancy
+    return jnp.stack((receiver_idx, sender_idx)), max_occupancy
 
   def neighbor_list_fn(position: Array,
                        neighbors: Optional[NeighborList] = None,
@@ -765,19 +766,23 @@ def neighbor_list(displacement_or_metric: DisplacementOrMetricFn,
         _extra_capacity = (extra_capacity if not is_sparse(format)
                            else N * extra_capacity)
         max_occupancy = int(occupancy * capacity_multiplier + _extra_capacity)
-        if max_occupancy > position.shape[0] and not is_sparse(format):
-          max_occupancy = position.shape[0]
-        if max_occupancy > occupancy:
-          padding = max_occupancy - occupancy
-          pad = N * jnp.ones((idx.shape[0], padding), dtype=idx.dtype)
-          idx = jnp.concatenate([idx, pad], axis=1)
+        if max_occupancy > idx.shape[-1]:
+          max_occupancy = idx.shape[-1]
+        if not is_sparse(format):
+          capacity_limit = N - 1 if mask_self else N
+        elif format is NeighborListFormat.Sparse:
+          capacity_limit = N * (N - 1) if mask_self else N**2
+        else:
+          capacity_limit = N * (N - 1) // 2
+        if max_occupancy > capacity_limit:
+          max_occupancy = capacity_limit
       idx = idx[:, :max_occupancy]
       update_fn = (neighbor_list_fn if neighbors is None else
                    neighbors.update_fn)
       return NeighborList(
           idx,
           position,
-          overflow | (occupancy >= max_occupancy),
+          overflow | (occupancy > max_occupancy),
           cl_capacity,
           max_occupancy,
           format,
