@@ -19,10 +19,13 @@
 
   In general, simulation code follows the same overall structure as optimizers
   in JAX. Simulations are tuples of two functions:
-    init_fn: function that initializes the  state of a system. Should take
-      positions as an ndarray of shape [n, output_dimension]. Returns a state
+
+    init_fn: 
+      Function that initializes the  state of a system. Should take
+      positions as an ndarray of shape `[n, output_dimension]`. Returns a state
       which will be a namedtuple.
-    apply_fn: function that takes a state and produces a new state after one
+    apply_fn: 
+      Function that takes a state and produces a new state after one
       step of optimization.
 
   One question that we need to think about is whether the simulations should
@@ -72,13 +75,12 @@ Simulator = Tuple[InitFn, ApplyFn]
 JAX MD includes integrators for deterministic simulations of the NVE, NVT, and
 NPT ensembles. For a qualitative description of statistical physics ensembles
 see the wikipedia article here:
-
 en.wikipedia.org/wiki/Statistical_ensemble_(mathematical_physics)
 
 Integrators are based direct translation method outlined in the paper,
 
 "A Liouville-operator derived measure-preserving integrator for molecular
- dynamics simulations in the isothermal–isobaric ensemble"
+dynamics simulations in the isothermal–isobaric ensemble"
 
 M. E. Tuckerman, J. Alejandre, R. López-Rendón, A. L Jochim, and G. J. Martyna
 J. Phys. A: Math. Gen. 39 5629 (2006)
@@ -127,13 +129,13 @@ class NVEState:
   the (E)nergy of the system are held fixed.
 
   Attributes:
-    position: An ndarray of shape [n, spatial_dimension] storing the position
+    position: An ndarray of shape `[n, spatial_dimension]` storing the position
       of particles.
-    velocity: An ndarray of shape [n, spatial_dimension] storing the velocity
+    velocity: An ndarray of shape `[n, spatial_dimension]` storing the velocity
       of particles.
-    force: An ndarray of shape [n, spatial_dimension] storing the force acting
+    force: An ndarray of shape `[n, spatial_dimension]` storing the force acting
       on particles from the previous step.
-    mass: A float or an ndarray of shape [n] containing the masses of the
+    mass: A float or an ndarray of shape `[n]` containing the masses of the
       particles.
   """
   position: Array
@@ -155,13 +157,13 @@ def nve(energy_or_force_fn: Callable[..., Array],
   Args:
     energy_or_force: A function that produces either an energy or a force from
       a set of particle positions specified as an ndarray of shape
-      [n, spatial_dimension].
-    shift_fn: A function that displaces positions, R, by an amount dR. Both R
-      and dR should be ndarrays of shape [n, spatial_dimension].
+      `[n, spatial_dimension]`.
+    shift_fn: A function that displaces positions, `R`, by an amount `dR`. Both `R`
+      and `dR` should be ndarrays of shape `[n, spatial_dimension]`.
     dt: Floating point number specifying the timescale (step size) of the
       simulation.
-    quant: Either a quantity.Energy or a quantity.Force specifying whether
-      energy_or_force is an energy or force respectively.
+    quant: Either a quantity. Energy or a quantity. Force specifying whether
+      `energy_or_force` is an energy or force respectively.
   Returns:
     See above.
   """
@@ -203,11 +205,11 @@ class NoseHooverChain:
   """State information for a Nose-Hoover chain.
 
   Attributes:
-    position: An ndarray of shape [chain_length] that stores the position of
+    position: An ndarray of shape `[chain_length]` that stores the position of
       the chain.
-    velocity: An ndarray of shape [chain_length] that stores the velocity of
+    velocity: An ndarray of shape `[chain_length]` that stores the velocity of
       the chain.
-    mass: An ndarray of shape [chain_length] that stores the mass of the
+    mass: An ndarray of shape `[chain_length]` that stores the mass of the
       chain.
     tau: The desired period of oscillation for the chain. Longer periods result
       is better stability but worse temperature control.
@@ -241,21 +243,21 @@ def nose_hoover_chain(dt: float,
 
   This function is used in simulations that sample from thermal ensembles by
   coupling the system to one, or more, Nose-Hoover chains. We use the direct
-  translation method outlined in [1] and the Nose-Hoover chains are updated
+  translation method outlined in Martyna et al. [#martyna92]_ and the Nose-Hoover chains are updated
   using two half steps: one at the beginning of a simulation step and one at
   the end. The masses of the Nose-Hoover chains are updated automatically to
   enforce a specific period of oscillation, `tau`. Larger values of `tau` will
   yield systems that reach the target temperature more slowly but are also more
   stable.
 
-  As described in [1], the Nose-Hoover chain often evolves on a faster
+  As described in Martyna et al. [#martyna92]_, the Nose-Hoover chain often evolves on a faster
   timescale than the rest of the simulation. Therefore, it sometimes necessary
   to integrate the chain over several substeps for each step of MD. To do this
   we follow the Suzuki-Yoshida scheme. Specifically, we subdivide our chain
   simulation into :math:`n_c` substeps. These substeps are further subdivided into
   :math:`n_sy` steps. Each :math:`n_sy` step has length :math:`\delta_i = \Delta t w_i / n_c`
   where :math:`w_i` are constants such that :math:`\sum_i w_i = 1`. See the table of
-  Suzuki_Yoshida weights above for specific values. The number of substeps
+  Suzuki-Yoshida weights above for specific values. The number of substeps
   and the number of Suzuki-Yoshida steps are set using the `chain_steps` and
   `sy_steps` arguments.
 
@@ -274,11 +276,11 @@ def nose_hoover_chain(dt: float,
       simulation.
     chain_length: An integer specifying the number of particles in
       the Nose-Hoover chain.
-    chain_steps: An integer specifying the number, :math:`n_c`, of outer substeps.
+    chain_steps: An integer specifying the number :math:`n_c` of outer substeps.
     sy_steps: An integer specifying the number of Suzuki-Yoshida steps. This
-      must be either 1, 3, 5, or 7.
+      must be either `1`, `3`, `5`, or `7`.
     tau: A floating point timescale over which temperature equilibration occurs.
-      Measured in units of dt. The performance of the Nose-Hoover chain
+      Measured in units of `dt`. The performance of the Nose-Hoover chain
       thermostat can be quite sensitive to this choice.
   Returns:
     A triple of functions that initialize the chain, do a half step of
@@ -388,13 +390,13 @@ class NVTNoseHooverState:
 
   Attributes:
     position: The current position of particles. An ndarray of floats
-      with shape [n, spatial_dimension].
+      with shape `[n, spatial_dimension]`.
     velocity: The velocity of particles. An ndarray of floats
-      with shape [n, spatial_dimension].
+      with shape `[n, spatial_dimension]`.
     force: The current force on the particles. An ndarray of floats with shape
-      [n, spatial_dimension].
+      `[n, spatial_dimension]`.
     mass: The mass of the particles. Can either be a float or an ndarray
-      of floats with shape [n].
+      of floats with shape `[n]`.
     chain: The variables describing the Nose-Hoover chain.
   """
   position: Array
@@ -416,16 +418,16 @@ def nvt_nose_hoover(energy_or_force_fn: Callable[..., Array],
 
   Samples from the canonical ensemble in which the number of particles (N),
   the system volume (V), and the temperature (T) are held constant. We use a
-  Nose Hoover Chain (NHC) thermostat described in [1, 2, 3]. We follow the
-  direct translation method outlined in [3] and the interested reader might
-  want to look at that paper as a reference.
+  Nose Hoover Chain (NHC) thermostat described in [#martyna92]_ [#martyna98]_ [#tuckerman]_ . 
+  We follow the direct translation method outlined in Tuckerman et al. [#tuckerman]_ 
+  and the interested reader might want to look at that paper as a reference.
 
   Args:
     energy_or_force: A function that produces either an energy or a force from
       a set of particle positions specified as an ndarray of shape
-      [n, spatial_dimension].
-    shift_fn: A function that displaces positions, R, by an amount dR. Both R
-      and dR should be ndarrays of shape [n, spatial_dimension].
+      `[n, spatial_dimension]`.
+    shift_fn: A function that displaces positions, `R`, by an amount `dR`. Both `R`
+      and `dR` should be ndarrays of shape `[n, spatial_dimension]`.
     dt: Floating point number specifying the timescale (step size) of the
       simulation.
     kT: Floating point number specifying the temperature in units of Boltzmann
@@ -435,24 +437,25 @@ def nvt_nose_hoover(energy_or_force_fn: Callable[..., Array],
       the Nose-Hoover chain.
     chain_steps: An integer specifying the number, :math:`n_c`, of outer substeps.
     sy_steps: An integer specifying the number of Suzuki-Yoshida steps. This
-      must be either 1, 3, 5, or 7.
+      must be either `1`, `3`, `5`, or `7`.
     tau: A floating point timescale over which temperature equilibration occurs.
-      Measured in units of dt. The performance of the Nose-Hoover chain
+      Measured in units of `dt`. The performance of the Nose-Hoover chain
       thermostat can be quite sensitive to this choice.
   Returns:
     See above.
 
-  [1] Martyna, Glenn J., Michael L. Klein, and Mark Tuckerman.
-      "Nose-Hoover chains: The canonical ensemble via continuous dynamics."
-      The Journal of chemical physics 97, no. 4 (1992): 2635-2643.
-  [2] Martyna, Glenn, Mark Tuckerman, Douglas J. Tobias, and Michael L. Klein.
-      "Explicit reversible integrators for extended systems dynamics."
-      Molecular Physics 87. (1998) 1117-1157.
-  [3] Tuckerman, Mark E., Jose Alejandre, Roberto Lopez-Rendon,
-      Andrea L. Jochim, and Glenn J. Martyna.
-      "A Liouville-operator derived measure-preserving integrator for molecular
-      dynamics simulations in the isothermal-isobaric ensemble."
-      Journal of Physics A: Mathematical and General 39, no. 19 (2006): 5629.
+  .. rubric:: References
+  .. [#martyna92] Martyna, Glenn J., Michael L. Klein, and Mark Tuckerman.
+    "Nose-Hoover chains: The canonical ensemble via continuous dynamics."
+    The Journal of chemical physics 97, no. 4 (1992): 2635-2643.
+  .. [#martyna98] Martyna, Glenn, Mark Tuckerman, Douglas J. Tobias, and Michael L. Klein.
+    "Explicit reversible integrators for extended systems dynamics."
+    Molecular Physics 87. (1998) 1117-1157.
+  .. [#tuckerman] Tuckerman, Mark E., Jose Alejandre, Roberto Lopez-Rendon,
+    Andrea L. Jochim, and Glenn J. Martyna.
+    "A Liouville-operator derived measure-preserving integrator for molecular
+    dynamics simulations in the isothermal-isobaric ensemble."
+    Journal of Physics A: Mathematical and General 39, no. 19 (2006): 5629.
   """
   dt = f32(dt)
   if tau is None:
@@ -530,13 +533,13 @@ class NPTNoseHooverState:
 
   Attributes:
     position: The current position of particles. An ndarray of floats
-      with shape [n, spatial_dimension].
+      with shape `[n, spatial_dimension]`.
     velocity: The velocity of particles. An ndarray of floats
-      with shape [n, spatial_dimension].
+      with shape `[n, spatial_dimension]`.
     force: The current force on the particles. An ndarray of floats with shape
-      [n, spatial_dimension].
+      `[n, spatial_dimension]`.
     mass: The mass of the particles. Can either be a float or an ndarray
-      of floats with shape [n].
+      of floats with shape `[n]`.
     reference_box: A box used to measure relative changes to the simulation
       environment.
     box_position: A positional degree of freedom used to describe the current
@@ -594,17 +597,18 @@ def npt_nose_hoover(energy_fn: Callable[..., Array],
   """Simulation in the NPT ensemble using a pair of Nose Hoover Chains.
 
   Samples from the canonical ensemble in which the number of particles (N),
-  the system pressure (P), and the temperature (T) are held constant. We use a
-  pair of Nose Hoover Chains (NHC) described in [1, 2, 3] coupled to the
+  the system pressure (P), and the temperature (T) are held constant. 
+  We use a pair of Nose Hoover Chains (NHC) described in 
+  [#martyna92]_ [#martyna98]_ [#tuckerman]_ coupled to the
   barostat and the thermostat respectively. We follow the direct translation
-  method outlined in [3] and the interested reader might want to look at that
-  paper as a reference.
+  method outlined in Tuckerman et al. [#tuckerman]_ and the interested reader 
+  might want to look at that paper as a reference.
 
   Args:
     energy_fn: A function that produces either an energy from a set of particle
-      positions specified as an ndarray of shape [n, spatial_dimension].
-    shift_fn: A function that displaces positions, R, by an amount dR. Both R
-      and dR should be ndarrays of shape [n, spatial_dimension].
+      positions specified as an ndarray of shape `[n, spatial_dimension]`.
+    shift_fn: A function that displaces positions, `R`, by an amount `dR`. Both `R`
+      and `dR` should be ndarrays of shape `[n, spatial_dimension]`.
     dt: Floating point number specifying the timescale (step size) of the
       simulation.
     pressure: Floating point number specifying the target pressure. To update
@@ -623,17 +627,6 @@ def npt_nose_hoover(energy_fn: Callable[..., Array],
   Returns:
     See above.
 
-  [1] Martyna, Glenn J., Michael L. Klein, and Mark Tuckerman.
-      "Nose-Hoover chains: The canonical ensemble via continuous dynamics."
-      The Journal of chemical physics 97, no. 4 (1992): 2635-2643.
-  [2] Martyna, Glenn, Mark Tuckerman, Douglas J. Tobias, and Michael L. Klein.
-      "Explicit reversible integrators for extended systems dynamics."
-      Molecular Physics 87. (1998) 1117-1157.
-  [3] Tuckerman, Mark E., Jose Alejandre, Roberto Lopez-Rendon,
-      Andrea L. Jochim, and Glenn J. Martyna.
-      "A Liouville-operator derived measure-preserving integrator for molecular
-      dynamics simulations in the isothermal-isobaric ensemble."
-      Journal of Physics A: Mathematical and General 39, no. 19 (2006): 5629.
   """
 
   t = f32(dt)
@@ -827,13 +820,13 @@ class NVTLangevinState:
 
   Attributes:
     position: The current position of the particles. An ndarray of floats with
-      shape [n, spatial_dimension].
+      shape `[n, spatial_dimension]`.
     velocity: The velocity of particles. An ndarray of floats with shape
-      [n, spatial_dimension].
+      `[n, spatial_dimension]`.
     force: The (non-stochastic) force on particles. An ndarray of floats with
-      shape [n, spatial_dimension].
+      shape `[n, spatial_dimension]`.
     mass: The mass of particles. Will either be a float or an ndarray of floats
-      with shape [n].
+      with shape `[n]`.
     rng: The current state of the random number generator.
   """
   position: Array
@@ -858,14 +851,14 @@ def nvt_langevin(energy_or_force: Callable[..., Array],
   ODE described by a friction coefficient and noise of a given covariance.
 
   Our implementation follows the excellent set of lecture notes by Carlon,
-  Laleman, and Nomidis [1].
+  Laleman, and Nomidis [#carlon]_ .
 
   Args:
     energy_or_force: A function that produces either an energy or a force from
       a set of particle positions specified as an ndarray of shape
-      [n, spatial_dimension].
-    shift_fn: A function that displaces positions, R, by an amount dR. Both R
-      and dR should be ndarrays of shape [n, spatial_dimension].
+      `[n, spatial_dimension]`.
+    shift_fn: A function that displaces positions, `R`, by an amount `dR`. Both `R`
+      and `dR` should be ndarrays of shape `[n, spatial_dimension]`.
     dt: Floating point number specifying the timescale (step size) of the
       simulation.
     kT: Floating point number specifying the temperature in units of Boltzmann
@@ -878,9 +871,10 @@ def nvt_langevin(energy_or_force: Callable[..., Array],
   Returns:
     See above.
 
-    [1] E. Carlon, M. Laleman, S. Nomidis. "Molecular Dynamics Simulation."
-        http://itf.fys.kuleuven.be/~enrico/Teaching/molecular_dynamics_2015.pdf
-        Accessed on 06/05/2019.
+  .. rubric:: References
+  .. [#carlon] E. Carlon, M. Laleman, S. Nomidis. "Molecular Dynamics Simulation."
+    http://itf.fys.kuleuven.be/~enrico/Teaching/molecular_dynamics_2015.pdf
+    Accessed on 06/05/2019.
   """
 
   force_fn = quantity.canonicalize_force(energy_or_force)
@@ -938,9 +932,9 @@ class BrownianState:
 
   Attributes:
     position: The current position of the particles. An ndarray of floats with
-      shape [n, spatial_dimension].
-    mass: The mmass of particles. Will either be a float or an ndarray of floats
-      with shape [n].
+      shape `[n, spatial_dimension]`.
+    mass: The mass of particles. Will either be a float or an ndarray of floats
+      with shape `[n]`.
     rng: The current state of the random number generator.
   """
   position: Array
@@ -959,14 +953,14 @@ def brownian(energy_or_force: Callable[..., Array],
   regime of Langevin dynamics. However, in this case we don't need to take into
   account velocity information and the dynamics simplify. Consequently, when
   Brownian dynamics can be used they will be faster than Langevin. As in the
-  case of Langevin dynamics our implementation follows [1].
+  case of Langevin dynamics our implementation follows Carlon et al. [#carlon]_
 
   Args:
     energy_or_force: A function that produces either an energy or a force from
       a set of particle positions specified as an ndarray of shape
-      [n, spatial_dimension].
-    shift_fn: A function that displaces positions, R, by an amount dR. Both R
-      and dR should be ndarrays of shape [n, spatial_dimension].
+      `[n, spatial_dimension]`.
+    shift_fn: A function that displaces positions, `R`, by an amount `dR`. Both `R`
+      and `dR` should be ndarrays of shape `[n, spatial_dimension]`.
     dt: Floating point number specifying the timescale (step size) of the
       simulation.
     kT: Floating point number specifying the temperature in units of Boltzmann
@@ -977,10 +971,6 @@ def brownian(energy_or_force: Callable[..., Array],
 
   Returns:
     See above.
-
-    [1] E. Carlon, M. Laleman, S. Nomidis. "Molecular Dynamics Simulation."
-        http://itf.fys.kuleuven.be/~enrico/Teaching/molecular_dynamics_2015.pdf
-        Accessed on 06/05/2019.
   """
 
   force_fn = quantity.canonicalize_force(energy_or_force)
@@ -1027,7 +1017,7 @@ class SwapMCState:
 
   Attributes:
     md: A NVTNoseHooverState containing continuous molecular dynamics data.
-    sigma: An [n,] array of particle radii.
+    sigma: An `[n,]` array of particle radii.
     key: A JAX PRGNKey used for random number generation.
     neighbor: A NeighborList for the system.
   """
@@ -1050,7 +1040,8 @@ def hybrid_swap_mc(space_fns: space.Space,
                    ) -> Simulator:
   """Simulation of Hybrid Swap Monte-Carlo.
 
-  This code simulates the hybrid Swap Monte Carlo algorithm introduced in [1].
+  This code simulates the hybrid Swap Monte Carlo algorithm introduced in 
+  Berthier et al. [#berthier]_
   Here an NVT simulation is performed for `t_md` time and then `N_swap` MC
   moves are performed that swap the radii of randomly chosen particles. The
   random swaps are accepted with Metropolis-Hastings step. Each call to the
@@ -1081,10 +1072,10 @@ def hybrid_swap_mc(space_fns: space.Space,
   Returns:
     See above.
 
-  [1] L. Berthier, E. Flenner, C. J. Fullerton, C. Scalliet, and M. Singh.
-      "Efficient swap algorithms for molecular dynamics simulations of
-       equilibrium supercooled liquids"
-      J. Stat. Mech. (2019) 064004
+  .. rubric:: References
+  .. [#berthier] L. Berthier, E. Flenner, C. J. Fullerton, C. Scalliet, and M. Singh.
+    "Efficient swap algorithms for molecular dynamics simulations of
+    equilibrium supercooled liquids", J. Stat. Mech. (2019) 064004
   """
   displacement_fn, shift_fn = space_fns
   metric_fn = space.metric(displacement_fn)
